@@ -1,70 +1,43 @@
 /*
+ * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
+ * @license AGPL-3.0
  *
- *    OPEN-XCHANGE legal information
+ * This code is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU Affero General Public License as published by
+ * the Free Software Foundation, either version 3 of the License, or
+ * (at your option) any later version.
  *
- *    All intellectual property rights in the Software are protected by
- *    international copyright laws.
+ * This program is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU Affero General Public License for more details.
  *
+ * You should have received a copy of the GNU Affero General Public License
+ * along with OX App Suite. If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
  *
- *    In some countries OX, OX Open-Xchange, open xchange and OXtender
- *    as well as the corresponding Logos OX Open-Xchange and OX are registered
- *    trademarks of the OX Software GmbH group of companies.
- *    The use of the Logos is not covered by the GNU General Public License.
- *    Instead, you are allowed to use these Logos according to the terms and
- *    conditions of the Creative Commons License, Version 2.5, Attribution,
- *    Non-commercial, ShareAlike, and the interpretation of the term
- *    Non-commercial applicable to the aforementioned license is published
- *    on the web site http://www.open-xchange.com/EN/legal/index.html.
- *
- *    Please make sure that third-party modules and libraries are used
- *    according to their respective licenses.
- *
- *    Any modifications to this package must retain all copyright notices
- *    of the original copyright holder(s) for the original code used.
- *
- *    After any such modifications, the original and derivative code shall remain
- *    under the copyright of the copyright holder(s) and/or original author(s)per
- *    the Attribution and Assignment Agreement that can be located at
- *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
- *    given Attribution for the derivative code and a license granting use.
- *
- *     Copyright (C) 2016-2020 OX Software GmbH
- *     Mail: info@open-xchange.com
- *
- *
- *     This program is free software; you can redistribute it and/or modify it
- *     under the terms of the GNU General Public License, Version 2 as published
- *     by the Free Software Foundation.
- *
- *     This program is distributed in the hope that it will be useful, but
- *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
- *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
- *     for more details.
- *
- *     You should have received a copy of the GNU General Public License along
- *     with this program; if not, write to the Free Software Foundation, Inc., 59
- *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
+ * Any use of the work other than as authorized under this license or copyright law is prohibited.
  *
  */
 
+
+
 package com.openexchange.imageconverter.client;
 
 import static org.apache.commons.lang.ArrayUtils.isEmpty;
 import static org.apache.commons.lang.StringUtils.isEmpty;
 import static org.apache.commons.lang.StringUtils.isNotEmpty;
-
 import java.io.ByteArrayInputStream;
 import java.io.ByteArrayOutputStream;
 import java.io.File;
 import java.io.IOException;
 import java.io.InputStream;
+import java.net.ConnectException;
 import java.util.List;
 import java.util.Map;
-
 import javax.net.ssl.SSLContext;
 import javax.net.ssl.SSLSocketFactory;
+import javax.ws.rs.ProcessingException;
 import javax.ws.rs.core.Response.Status;
-
 import org.apache.commons.fileupload.MultipartStream;
 import org.apache.commons.io.FileUtils;
 import org.apache.commons.io.IOUtils;
@@ -72,7 +45,6 @@ import org.apache.commons.lang.StringUtils;
 import org.json.JSONObject;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
-
 import com.google.common.base.Throwables;
 import com.openexchange.annotation.NonNull;
 import com.openexchange.annotation.Nullable;
@@ -187,7 +159,7 @@ public class ImageConverterClient implements IImageClient {
                         if (null != (tmpResponseFile = api.getImage(imageKey, requestFormat, implGetContext(context)))) {
                             ret = new ByteArrayInputStream(FileUtils.readFileToByteArray(tmpResponseFile));
                         }
-                    } catch (ApiException e) {
+                    } catch (ApiException | ProcessingException e) {
                         implHandleAPIException("Error in remote calling ImageConverter#getImage", e);
                     } catch (Exception e) {
                         throw new ImageConverterException("Error in remote calling ImageConverter#getImage", e);
@@ -232,7 +204,7 @@ public class ImageConverterClient implements IImageClient {
                                 }
                             }
                         }
-                    } catch (ApiException e) {
+                    } catch (ApiException | ProcessingException e) {
                         implHandleAPIException("Error in remote calling ImageConverter#getMetadata", e);
                     } catch (Exception e) {
                         throw new ImageConverterException("Error in remote calling ImageConverter#getMetadata", e);
@@ -273,7 +245,7 @@ public class ImageConverterClient implements IImageClient {
                                 ret = implCreateMetadataImage(fileInputStm, fileResponse.getHeaders());
                             }
                         }
-                    } catch (ApiException e) {
+                    } catch (ApiException | ProcessingException e) {
                         implHandleAPIException("Error in remote calling ImageConverter#getImageAndMetadata", e);
                     } catch (Exception e) {
                         throw new ImageConverterException("Error in remote calling ImageConverter#getImageAndMetadata", e);
@@ -308,7 +280,7 @@ public class ImageConverterClient implements IImageClient {
                     if (null != tmpInputFile) {
                         try {
                             api.cacheImage(imageKey, tmpInputFile, implGetContext(context));
-                        } catch (ApiException e) {
+                        } catch (ApiException | ProcessingException e) {
                             implHandleAPIException("Error in remote calling ImageConverter#cacheImage", e);
                         } finally {
                             FileUtils.deleteQuietly(tmpInputFile);
@@ -348,7 +320,7 @@ public class ImageConverterClient implements IImageClient {
                                 if (null != (tmpResponseFile = api.cacheAndGetImage(imageKey, requestFormat, tmpInputFile, implGetContext(context)))) {
                                     ret = new ByteArrayInputStream(FileUtils.readFileToByteArray(tmpResponseFile));
                                 }
-                            } catch (ApiException e) {
+                            } catch (ApiException | ProcessingException e) {
                                 implHandleAPIException("Error in remote calling ImageConverter#cacheAndGetImage", e);
                             } catch (Exception e) {
                                 throw new ImageConverterException("Error in remote calling ImageConverter#cacheAndGetImage", e);
@@ -400,7 +372,7 @@ public class ImageConverterClient implements IImageClient {
                                         ret = implCreateMetadataImage(fileInputStm, fileResponse.getHeaders());
                                     }
                                 }
-                            } catch (ApiException e) {
+                            } catch (ApiException | ProcessingException e) {
                                 implHandleAPIException("Error in remote calling ImageConverter#cacheAndGetImageAndMetadata", e);
                             } catch (Exception e) {
                                 throw new ImageConverterException("Error in remote calling ImageConverter#cacheAndGetImageAndMetadata", e);
@@ -435,7 +407,7 @@ public class ImageConverterClient implements IImageClient {
         if (null != api) {
             try {
                 api.clearImages(implGetContext(context));
-            } catch (ApiException e) {
+            } catch (ApiException | ProcessingException e) {
                 implHandleAPIException("Error in remote calling ImageConverter#clearImages with context: " + context, e);
             } finally {
                 m_apiProvider.release(api);
@@ -458,7 +430,7 @@ public class ImageConverterClient implements IImageClient {
         if (null != api) {
             try {
                 api.clearImagesByKey(imageKey);
-            } catch (ApiException e) {
+            } catch (ApiException | ProcessingException e) {
                 implHandleAPIException("Error in remote calling ImageConverter#clearImagesByKey", e);
             } finally {
                 m_apiProvider.release(api);
@@ -481,7 +453,7 @@ public class ImageConverterClient implements IImageClient {
         if (null != api) {
             try {
                 ret = api.getKeyCount(implGetContext(context)).getCount().longValue();
-            } catch (ApiException e) {
+            } catch (ApiException | ProcessingException e) {
                 implHandleAPIException("Error in remote calling ImageConverter#getKeyCount with context: " + context, e);
             } finally {
                 m_apiProvider.release(api);
@@ -507,7 +479,7 @@ public class ImageConverterClient implements IImageClient {
             try {
                 final List<String> keyList = api.getKeys(implGetContext(context)).getKeys();
                 ret = keyList.toArray(new String[keyList.size()]);
-            } catch (ApiException e) {
+            } catch (ApiException | ProcessingException e) {
                 implHandleAPIException("Error in remote calling ImageConverter#getKeys with context: " + context, e);
             } finally {
                 m_apiProvider.release(api);
@@ -544,7 +516,7 @@ public class ImageConverterClient implements IImageClient {
             try {
                 ret = api.status("false");
             } catch (ApiException e) {
-                ImageConverterException ice = implWrapAPIException("Error in remote calling ImageConverter#status", e);
+                ImageConverterException ice = implWrapAPIException("Error in remote calling ImageConverter#status", e, e.getCode());
                 if (ice != null) {
                     throw OXException.general(ice.getMessage(), ice);
                 }
@@ -587,28 +559,32 @@ public class ImageConverterClient implements IImageClient {
 
     // - Implementation --------------------------------------------------------
 
-    private void implHandleAPIException(final String msg, final ApiException e) throws ImageConverterException {
-        final ImageConverterException ice = implWrapAPIException(msg, e);
+    private void implHandleAPIException(final String msg, final Exception e) throws ImageConverterException {
+        final ImageConverterException ice = implWrapAPIException(msg, e, (e instanceof ApiException) ? ((ApiException) e).getCode() : 503);
         if (ice != null) {
             throw ice;
         }
     }
 
-    private ImageConverterException implWrapAPIException(final String msg, final ApiException e) {
+    private ImageConverterException implWrapAPIException(final String msg, final Exception e, int statusCode) {
         final StringBuilder throwMessageBuilder = new StringBuilder(StringUtils.isNotEmpty(msg) ? msg : "IC client received unknown API exception");
         boolean throwException = true;
 
         if (null != e) {
             final Throwable cause = Throwables.getRootCause(e);
             final String causeMessage = (null != cause) ? cause.getMessage() : null;
-            final int statusCode = e.getCode();
 
-            if (Status.NOT_FOUND.getStatusCode() == statusCode) {
+            if (Status.NO_CONTENT.getStatusCode() == statusCode) {
                 throwException = false;
 
-                LOG.trace("IC client received a resource NOT_FOUND error from server => proceeding normally");
+                if (LOG.isTraceEnabled()) {
+                    LOG.trace("IC client received a resource NOT_FOUND error from server => proceeding normally");
+                }
             } else {
-                if ((e.getCode() == 503) || (cause instanceof IOException) || StringUtils.containsIgnoreCase(causeMessage, "terminated")) {
+                if ((statusCode == 404) || (statusCode == 503) ||
+                    (cause instanceof IOException) || (cause instanceof ConnectException) || (cause instanceof ProcessingException) ||
+                    StringUtils.containsIgnoreCase(causeMessage, "terminated")) {
+
                     m_remoteValidator.connectionLost();
 
                     LOG.warn(new StringBuilder("IC client lost remote connection (cause: ").
